@@ -33,9 +33,10 @@
 #  define KDECORATIONS_PRIVATE_DEPRECATED_NO_EXPORT KDECORATIONS_PRIVATE_NO_EXPORT KDECORATIONS_PRIVATE_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KDECORATIONS_PRIVATE_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KDECORATIONS_PRIVATE_NO_DEPRECATED
+#    define KDECORATIONS_PRIVATE_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
